---
layout: page
title: Exams
description: Overview of what to expect for the MUDE Q1 & Q2 Exams.
nav_order: 5
nav_exclude: false
# math: mathjax
---

# Written Exams

The exam schedules can be found in [MyTimetable](https://mytimetable.tudelft.nl/schedule) (but note that the exam room may change up to 1 week prior to the exam). Most importantly, remember:

1. you must register for each MUDE exam separately, and 
2. don't wait until the last minute---registration closes 2 weeks before the exam!

[Exam registration requirements can be found here](https://www.tudelft.nl/en/student/education/courses-and-examinations/examinations/registration-for-examinations).

## Exam Format

Both exams (and resits) are paper-based. Scrap paper is provided, but answers will be written on the printed exam paper. Pre-programmed calculators, books and lectures notes are not allowed. The student must only bring writing and drawing materials, and a scientific calculator.

Programming-specific questions will make up a maximum of 10% of the total exam grade and will be based on the topics and applications covered in the weekly Programming Assignments and Group Assignments. However, note that questions related to the non-programming part of the course may rely on code and programming concepts (for example, illustrating a numerical result in the form of Python output), so if you skip the programming part of the course entirely, you may impact much more than 10% of your exam grade. In other words: _complete your Programming Assignments and participate actively in the Group Assignments and you won't have a problem._

As the exam is closed-book, we will provide equations as needed either with a **formula sheet** or directly in the printed exam document. You can find a sample exam [here](https://mude.citg.tudelft.nl/2023/files/Exams/){:target="_blank"} in the course files, which was printed on A4 paper for the exam.

If you have questions about which formulas may be provided during the exam, use the Answers Platform (link in top right).

## Sample Exams

Exams and resits from last year are given here as an example of the format and content (they are also available via the general Files page). The PDF file shows the exam format that the student can expect in the exam (i.e., if printed on A4 paper, this is exactly where the answers would be written). The HTML files illustrate the exam questions and answers. 

Note that for the 2022-2023 academic year the format of the module and specific topics were significantly different. This is indicated below. 

Programming questions from previous years illustrate how programming will be asked, but not necessarily the content. As the scope of Programming Assignments changes from year to year, you may see topics that are unfamiliar to you. In this case, remember: _the content from the Programming Assignments this year dictates the scope of programming questions on the exam!_

Where changes have been made, an indication is provided for which questions in each exam are relevant for Q1 and Q2 this year. See the following section for more details on changes from year to year.

- **Exam Q1 2022:** [PDF Exam (no solution)](https://mude.citg.tudelft.nl/2023/files/Exams/22_Q1.pdf){:target="_blank"}and [HTML (solution)](https://mude.citg.tudelft.nl/2023/files/Exams/22_Q1.html){:target="_blank"}.
  - Questions that apply for Q1 this year: 3 to 8.
  - Questions that apply for Q2 this year: 2.
- **Resit Q1 2022:** [PDF Exam (no solution)](https://mude.citg.tudelft.nl/2023/files/Exams/22_Q1_resit.pdf){:target="_blank"} and [HTML (solution)](https://mude.citg.tudelft.nl/2023/files/Exams/22_Q1_resit.html){:target="_blank"}.
  - Questions that apply for Q1 this year: 3 to 8.
  - Questions that apply for Q2 this year: 2.
- **Exam Q2 2022:** [PDF Exam (no solution)](https://mude.citg.tudelft.nl/2023/files/Exams/22_Q2.pdf){:target="_blank"} and [HTML (solution)](https://mude.citg.tudelft.nl/2023/files/Exams/22_Q2.html){:target="_blank"}.
  - Question that apply for Q1 this year: 2.
  - Question that apply for Q2 this year: 3 to 10.
- **Resit Q2 2022:** [PDF Exam (no solution)](https://mude.citg.tudelft.nl/2023/files/Exams/22_Q2_resit.pdf){:target="_blank"} and [HTML (solution)](https://mude.citg.tudelft.nl/2023/files/Exams/22_Q2_resit.html){:target="_blank"}.
  - Question that apply for Q1 this year: 2
  - Question that apply for Q2 this year: 3 to 12.

### Detailed Overview of Changes from Previous Years

The purpose of this section is to help you determine which exam questions from the sample exams are relevant for you this year. You are not expected to study the changes in MUDE contents from year to year.

The biggest change was between the 2022-2023 and 2023-2024 academic years. Specific differences include:
- Inclusion of one week of finite volume method.
- Finite difference no longer included in study material for Q2 (now in Q1).
- Finite element material is reduced, relative to 2022.
- Extreme value analysis is material is expanded and now in Q2 instead of Q1.

Please also keep in mind the following when using the exams from 2022-2023:
- There were around 8 or 9 "Questions" on the exam, each with multiple sub-questions. This year there will be fewer "Questions," which of course means the value (in points) will be more for each of them.
- The style of questions in the sample exams is representative of the style of questions you will see this year.
- Some questions or portions of questions may make reference to topics that have not been covered in the current academic year. For example, 'W-test' in sensing and observation theory was not covered, so you may exclude this topic for your studies.
- The scope of the exam is governed by the contents of the online textbook, and exceptions are stated in the book. If you see a discrepancy between the textbook and the sample exams, the textbook governs.
- A portion of the questions this year will take inspiration from the assignments we have done on Wednesday and Friday (but not all of the questions); it would be wise to review this when preparing for the exam.