---
layout: page
title: Assignment Portfolio
description: Overview of Assignment Portfolio (particularly the Group Assignments) and policies for report writing, directory structure and code documentation.
nav_order: 4
nav_exclude: false
permalink: /portfolio/
# math: mathjax
---

# Assignment Portfolio

The Assignment Portfolio consists of three things: Programming Assignments, BuddyChecks and Group Assignments. As such, it is based on individual and group work.

In particular, the Group Assignments consist of the following weekly elements:
1. A set of digitial files that you submit every Friday at the end of the in-class sessions (except Weeks 1.2 and 1.3).
2. BuddyCheck, a weekly questionnaire administered via Brightspace to evaluate yourself and your group members.
3. Weekly reflections to improve the performance of your group and keep issues from becoming serious; recommended to occur at the beginning of the Wednesday in-class sessions, but this can be flexible.  

Key components of the Assignment Portfolio are described below.

This page contains the following sections:
- [Assignment Portfolio](#assignment-portfolio)
  - [Programming Assignments (PA)](#programming-assignments-pa)
  - [Peer Feedback with Buddycheck](#peer-feedback-with-buddycheck)
  - [Group Assignments](#group-assignments)
  - [Grading Criteria: Assignment Portfolio](#grading-criteria-assignment-portfolio)
  - [Procedures and Conduct](#procedures-and-conduct)
    - [As a Group](#as-a-group)
    - [As an Individual Student](#as-an-individual-student)

## Programming Assignments (PA)

A Programming Assignment is provided each week to introduce a few relevant concepts that are expected to be applied directly in the Group Assignment for that week. Programming Assignments are automatically graded after submitting them to GitLab and are assessed on a pass/no pass basis. You may resubmit as many times as needed to pass the assignment before the deadline at the end of each quarter.

You do not have to submit PA 1.1 and 1.2.

Programming Assignments will be checked for a passing grade periodically throughout each week; **additional information will be provided later in Q1.**

## Peer Feedback with Buddycheck

*Buddycheck* is a learning tool designed to help peer evaluation amongst your group in a constructive and transparent way. A Buddycheck form must be submitted every week (you will recieve an announcement via Brightspace).

In addition to providing an opportunity for you to reflect on the performance of your group, and your role therein, the MUDE team will monitor the results and help guide those that may not be contributing in a productive and/or conscientious way. MUDE instructors may reach out to groups or individuals throughout the module, if necessary, and may alter the terms of Group Assignments for individuals. If after an initial warning, a second warning is issued, it may elicit in removal from the group, and the Assignment Portfolio for that quarter must be [completed individually](#as-an-individual-student).

The first BuddyCheck will be assigned in Week 1.1.

**Additional information about BuddyCheck will be provided in Week 1.2.**

## Group Assignments

The work you turn in with your group each Friday will be graded out of 10 points.

There are a number of requirements that will be enforced for the **Group Assignment Reports**, which will be submitted as a combination of **Jupyter Notebooks**, **Python** and **Markdown** files. While providing the capability to present a wide variety of rich formatting, as well as facilitating computation, it is easy to produce documents that are simply un-readable --- these reporting requirements are designed to prevent that. Despite being part of your grade, these are generally good practices, and you will benefit by getting into the habit of applying these in your daily practice. 

To help you get familiar with notebooks and how they can be used to write readable reports, we will slowly introduce concepts to you throughout the module. For example, the Group Assignments during Weeks 1.1 and 1.2 will give you a mostly-completed notebook to start with, whereas by the end of Q2 you may be creating notebooks and Markdown files from scratch.

**This section will be updated later in Q1, as the first two weeks are used to get you used to the Group Assignment format.**

## Grading Criteria: Assignment Portfolio

The Assignment Portfolio will be determined based on the total number of points earned on the following:
- Group Assignments: 10 points each per week (maximum of 140 points)
- Programming Assignments: 2.5 points (maximum of 35 points) 
- Buddycheck: 2 points each (maximum of 28 points)

Note that all assignments during the first two weeks are ungraded, so points are calculated over 14 weeks (6 in Q1 and 8 in Q2), resulting in a maximum possible of 203 points.

Assignment Portfolio Grade is assigned until higherbracket reached; for example, 163 is a 7.0, 164 is a 7.5	
        
| points | % of max | Grade* |
| :---: | :---: | :---: |
| 203  |  100%   | 10.0 |
| 200  |  99%	 | 9.5 |
| 191  |  94%	 | 9.0 |
| 182  |  90%	 | 8.5 |
| 173  |  85%	 | 8.0 |
| 164  |  81%	 | 7.5 |
| 156  |  77%	 | 7.0 |
| 149  |  73%	 | 6.5 |
| 142  |  70%	 | 6.0 |
| 125  |  62%	 | 5.5 |
| 102  |  50%	 | 5.0 |
| 81   |  40%	 | 4.0 |
| 61   |  30%	 | 3.0 |
| 41   |  20%	 | 2.0 |
| 21   |  10%	 | 1.0 |
| 1	   |  0%	 | 0.0 |

Note that active participation in the Programming Assignments and Buddy Checks along with an average score of 6 on the Group Assignments would provide just enough points to pass the Assignment Portfolio with a 6.0 (i.e., 30+28+84=142).

## Procedures and Conduct

### As a Group

Option 1 (default---and strongly recommended!)
* submit each Group Assignment report as specified each Friday at 12:30 and participate fairly with your group and you will receive timely feedback and keep up with the course contents

Option 2: you don't submit a Group Assignment (or are unable to do so for any valid reason)
* notify instructors as soon as possible that you are not able to submit a Group Assignment

If you receive an insufficient score (<5.8) for a single Group Assignment you are not allowed an opportunity to repair this. If you receive an insufficient score (<5.8) for the entire Assignment Portfolio, you must notify the instructors that you would like to do a resit prior to the first day of the 3rd quarter. A new assignment and timeline will be communicated to you shortly thereafter; this approach will result in maximum grade of 6.0 for the Assignment Portfolio.

### As an Individual Student

Students that have been removed from their group for any reason will complete the Assignment Portfolio for that quarter individually. This can be done in either quarter, with a maximum grade of 6.0. Completing the Assignment Portfolio in one quarter does not preclude participating in a group and receiving the group grade for the other quarter. The assignment scope and timeline will be communicated to you on a case-by-case basis.